@@ -1,14 +1,14 @@
 package Dist::Zilla::PluginBundle::AMD;
-# git description: v0.010-2-g993fa5a
-
 BEGIN {
   $Dist::Zilla::PluginBundle::AMD::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Dist::Zilla::PluginBundle::AMD::VERSION = '0.011';
+  $Dist::Zilla::PluginBundle::AMD::VERSION = '4.0.3';
 }
 # ABSTRACT: Build your distributions like AMD does
 
+
+
 use Moose 1.00;
 use Method::Signatures::Simple;
 use Moose::Util::TypeConstraints;
@@ -86,12 +86,6 @@ has disable_trailing_whitespace_tests => (
     default => 0,
 );
 
-has disable_tab_tests => (
-    is      => 'ro',
-    isa     => Bool,
-    default => 0,
-);
-
 has bugtracker_url => (
     isa     => Uri,
     coerce  => 1,
@@ -327,11 +321,9 @@ method configure {
         MetaJSON
         PkgVersion
         PodSyntaxTests
+        NoTabsTests
     ));
 
-    $self->add_plugins('NoTabsTests')
-        unless $self->disable_tab_tests;
-
     $self->add_plugins('PodCoverageTests')
         unless $self->disable_pod_coverage_tests;
 
@@ -349,7 +341,7 @@ method configure {
             do_metadata => 1,
         }],
         [EOLTests => {
-            trailing_whitespace => $self->disable_trailing_whitespace_tests ? 0 : 1,
+            trailing_whitespace => !$self->disable_trailing_whitespace_tests,
         }],
     );
 
@@ -364,7 +356,7 @@ method configure {
     $self->add_plugins('AutoPrereqs') if $self->auto_prereqs;
 
 
-    $self->add_plugins('Git::Describe');
+
     $self->add_plugins('CheckChangesHasContent');
 
     $self->add_plugins(['NextRelease' =>
@@ -382,7 +374,7 @@ method configure {
             $self->add_plugins('Git::NextVersion');
     }
 
-    $self->add_bundle('@Git');
+    $self->add_bundle('Git');
 }
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -441,7 +433,6 @@ It is roughly equivalent to:
   config_plugin = @AMD
 
   [AutoPrereqs]
-  [Git::Describe]
 
   [CheckChangesHasContent]
 
